@@ -1,5 +1,5 @@
 """Python client lib for Solarfocus"""
-__version__ = "2.0.3"
+__version__ = "2.0.5"
 
 import logging
 from enum import Enum
@@ -295,6 +295,10 @@ class SolarfocusAPI:
     @property
     def pb_log_wood_therminator(self) -> float:
         return self.pelletsboiler.log_wood.scaled_value
+    
+    @property
+    def system(self): 
+        return self._system
 
 
     def __init__(self, conn:ModbusTcpClient,system:Systems=Systems.Vampair,slave_id:int=SLAVE_ID):
@@ -307,6 +311,7 @@ class SolarfocusAPI:
         self.pelletsboiler = ComponentFactory.pelletsboiler(system)
         self.buffer = ComponentFactory.buffer(system)
         self._slave_id = slave_id
+        self._system = system
 
     def connect(self):
         """Connect to Solarfocus eco manager-touch"""
@@ -435,13 +440,14 @@ class SolarfocusAPI:
         """Set Photovoltaic"""
         return self.__write_register(self.photovoltaic.grid_im_export,value)
     
-    def __write_register(self,data_value:DataValue, value:int, check_connection:bool = True) -> bool:
+    def __write_register(self,data_value:DataValue, value:float, check_connection:bool = True) -> bool:
         """Internal methode to write a value to the modbus server"""
         if check_connection and not self.is_connected:
             logging.error("Connection to modbus is not established!")
             return False
         try:
-            scaled = int(data_value.reverse_scale(value))
+            scaled = int(data_value.scale(value))
+            logging.info(f"Scaled Value={scaled}")
             response = self._conn.write_registers(data_value.get_absolute_address(), [scaled], unit=self._slave_id)
             if response.isError():
                 logging.error(f"Error writing value={value} to register: {data_value.get_absolute_address()}: {response}")
